==> apache-karaf-cellar-4.1.2-src.zip: apache-karaf-cellar-4.1.2/itests/src/test/java/org/apache/karaf/cellar/itests/CellarBundleTest.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.karaf.cellar.itests;

import static org.junit.Assert.assertNotNull;

import org.apache.karaf.cellar.core.ClusterManager;
import org.apache.karaf.features.FeaturesService;
import org.junit.After;
import org.junit.Ignore;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.ops4j.pax.exam.junit.PaxExam;
import org.ops4j.pax.exam.spi.reactors.ExamReactorStrategy;
import org.ops4j.pax.exam.spi.reactors.PerClass;

@RunWith(PaxExam.class)
@ExamReactorStrategy(PerClass.class)
public class CellarBundleTest extends CellarTestSupport {

    @Test
    @Ignore
    public void testCellarBundleModule() throws Exception {
    	FeaturesService featuresService = getOsgiService(FeaturesService.class);
    	assertNotNull(featuresService);
    	
        installCellar();
        Thread.sleep(DEFAULT_TIMEOUT);
        ClusterManager clusterManager = getOsgiService(ClusterManager.class);
        assertNotNull(clusterManager);

        System.err.println(executeCommand("cluster:bundle-list default"));
    }

    @After
    public void tearDown() {
        try {
            unInstallCellar();
        } catch (Exception ex) {
            //Ignore
        }
    }

}

==> apache-karaf-cellar-4.4.8-src.zip: apache-karaf-cellar-4.4.8/itests/src/test/java/org/apache/karaf/cellar/itests/CellarBundleTest.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.karaf.cellar.itests;

import static org.junit.Assert.assertNotNull;

import org.apache.karaf.cellar.core.ClusterManager;
import org.apache.karaf.features.FeaturesService;
import org.apache.karaf.itests.KarafTestSupport;
import org.apache.karaf.jaas.boot.principal.RolePrincipal;
import org.junit.After;
import org.junit.Ignore;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.ops4j.pax.exam.Configuration;
import org.ops4j.pax.exam.Option;
import org.ops4j.pax.exam.junit.PaxExam;
import org.ops4j.pax.exam.karaf.options.KarafDistributionOption;
import org.ops4j.pax.exam.spi.reactors.ExamReactorStrategy;
import org.ops4j.pax.exam.spi.reactors.PerClass;

import java.util.stream.Stream;

@RunWith(PaxExam.class)
@ExamReactorStrategy(PerClass.class)
public class CellarBundleTest extends CellarTestSupport {

    @Test
    public void testCellarBundleModule() throws Exception {
        installCellar();

        String bundles = executeCommand("cluster:bundle-list default");
        System.out.println(bundles);
        assertNotNull(bundles);
        assertContains("local", bundles);
    }

}
